/* ----------------------------------------------------------------------------
 Copyright(c) Intel Corp.  ICSL 2001
 wdtTestCase.c:
 $Id: testwdt.c,v 1.1 2003/02/13 03:27:26 xling Exp $
 Description: watchdog timer test program
 ----------------------------------------------------------------------------*/
 /* ---- BEGIN: Revision History -----------------------------------------------
  Date          Author           Email                     Comments
  ========     ========         ============             ==============
  2001/12/15  Ling Xiaofeng     xiaofeng.ling@intel.com   Initial version
  2002/06/18  Ling Xiaofeng                               For new driver
 ------- END  : Revision History -------------------------------------------- */
#include <stdio.h>
#include <math.h>
#include <string.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <time.h>
#include <stdarg.h>
#include <unistd.h>
#define	MARGIN_TIME 60	
#define	PRE_TIME 1

#define	NORMAL_LOOP 3

void write_log(	char* strLog, ... ) 
{
	time_t t;    
	FILE *pfLogFile; 
	struct tm *time_now; 	
	va_list parameters;	
		
	pfLogFile = fopen("testwdt.log","a"); 
	if(pfLogFile == NULL)
	{ 
		perror("Fail to	open log file\n"); 
		exit(-1); 
	} 
	t = time( NULL ); 
	time_now = localtime( &t );	
	va_start( parameters, strLog ); 
	fprintf( pfLogFile, "%04u-%02u-%02u %02u:%02u:%02u ", time_now->tm_year + 1900, 
		time_now->tm_mon + 1, time_now->tm_mday, time_now->tm_hour, time_now->tm_min, 
		time_now->tm_sec ); 
	vfprintf( pfLogFile, strLog, parameters ); 
//	vprintf( strLog, parameters ); 
//	fprintf( pfLogFile, "\n" );	
	fflush(pfLogFile);
	fclose(pfLogFile);
	sync();
}

int main(int argc, const char *argv[])
{
	int fd;
	int i, j, nTime, uAction, uPreAction;
	int iRefresh, iMargin, iPre, iWarn, iNormal;
	char *pstr;	
	if(argc <3)
	{
		printf("Usage: wdtTestCase RefreshTime runtime wdt_margin wdt_pre action pre_action\n");
		exit(-1);
	}
	iRefresh=atoi(argv[1]);
	if(!(iRefresh>0)){
		printf("RefreshTime must be a positive integer\n");
		exit(-1);
	}

	/*check	pre-timeout and	time-out value*/
	nTime = argc >2 ? atoi(argv[2]):35;
	{	
		iMargin = argc > 3 ? atoi(argv[3]):0;
		iPre=argc > 4 ? atoi(argv[4]):0;
		uAction = argc > 5 ? strtoul(argv[5], &pstr, 0):0xff;		
		uPreAction = argc > 6 ? strtoul(argv[6], &pstr, 0):0xff;		
	}
/*
	if((iMargin<0)||(iPre<0)||(iMargin<iPre)){
		iMargin=MARGIN_TIME;
		//Pre=PRE_TIME;
	}
*/	
	iWarn = iMargin - iPre;
	write_log("=============Begin Test Case================\n");
	write_log("action=%d, pre_action=%d margin=%d, pre=%d, reflash_time=%d, TotalTime=%d\n",
		uAction, uPreAction, iMargin, iPre, iRefresh, nTime);	            
	fd = open("/dev/watchdog",O_WRONLY); /*	this will start	the timer */
	if(fd == -1)
	{
		write_log("watchdog open	error!\n");
		exit(1);
	}else{
		write_log("open watchdog....ok!\n");
	}
	if( write(fd,"\0",1) ==	-1) /*	refreshes (or resets) the timer	*/
		write_log("write device error!\n");
	else
		printf("write watchdog ok!\n");
	fsync(fd); /* make sure	it's written out to the	device */
	for(j = 1, i = 1; i <	nTime; i++)
	{
		sleep(1);
		printf("\010\010\033[1;33m%02d", i);
		fflush(NULL);
		if(j == iWarn)
			write_log("Pass by warning time\n");
		if(j == iMargin) 
			write_log("Pass by Margin time, no action\n");	
		if(i % iRefresh == 0)
		{
			j = 0;
			if( write(fd,"\0",1) ==	-1) /* refreshes (or resets) the timer */
				write_log("write	device error!\n");			
			write_log("fresh watch dog timer\n");
		}
		j++;
	}
	close(fd);
	write_log("close watch dog ok!\n");
}

  
